@@ -144,6 +144,28 @@ class Client:
         else:
             return self.host.replace("api2", "")
 
+    def create_datasource(self, name):
+        """Create a datasource in the Datasmoothie cloud.
+
+        Parameters
+        ----------
+        name : string
+            Name of the datasource.
+
+        Returns
+        -------
+        datasource
+            A datasmoothie.Datasource object.
+
+        """
+        payload = {"name": name}
+        resp = self.post_request(resource='datasource', data=payload)
+        result = json.loads(resp.content.decode('UTF-8'))
+        datasource = Datasource(client=self,
+                                meta=result,
+                                primary_key=result['pk'])
+        return datasource
+
     def get_datasource(self, primary_key):
         """Create a datasource object from information fetched from the API.
 
@@ -162,6 +184,7 @@ class Client:
         datasource = Datasource(client=self,
                                 meta=result,
                                 primary_key=result['pk'])
+        datasource.survey_meta = datasource.get_meta()
         return datasource
 
     def list_datasources(self):
